/*** Stand: 02.01.2019                                                                                                ***/

/************************************************************************************************************************/
/*********************************** Musterprogramm SAS DRG-STATISTIK ***************************************************/
 
/*** Hinweis: Das Musterprogramm dient Ihnen zur Orientierung bei der Erstellung Ihres Programmcodes. Das Ziel ist    ***/
/*** Ihre Outputfiles bestmglich fr die Geheimhaltungsprfung aufzubereiten.                                        ***/
/*** Bitte beachten Sie: Dieses Musterprogramm enthlt statistikspezifische Hilfestellungen zur Aufbereitung          ***/
/*** und Auswertung der von Ihnen beantragten DRG-Daten.                                                              ***/
                                                                                                                    
/************************************************************************************************************************/

/*** Dateien komprimieren und Outputausrichtung																		  ***/ 
options nocenter linesize=256 pagesize=90 compress=yes;

/*** Makros fr Pfade																								  ***/
%let datenpfad	= <Pfad wird im Forschungsdatenzentrum ergnzt>;
%let outputpfad = <Pfad wird im Forschungsdatenzentrum ergnzt>;

/*** Makros fr Datei- und Outputnamen																				  ***/
%let datenname  = drg;   
%let outputname = <Name des Outputs spezifizieren, z.B. outputname>; 		 									      													                   

/*** Libname vergeben																								  ***/
libname daten "&datenpfad";  


/************************************************************************************************************************/
/************************************************************************************************************************/
/************************************************************************************************************************/

/************************************************************************************************************************/
/************************************************************************************************************************/
/*** Titel des Projekts: <Adipositas bei Kindern und Erwachsenen>   												  ***/    
/*** Datengrundlage: 	 <DRG 2005-2016>																		      ***/
/***																												  ***/
/*** Dateiname des Programmcodes: <syntaxname.sas> 																	  ***/
/*** erstellt: 	<Datum> 																							  ***/
/*** von: 		<Name> 																							      ***/
/*** E-Mail: 	<E-Mail-Adresse> 																					  ***/
/*** Tel.		<Telefonnummer> 																					  ***/
/*** 																												  ***/
/*** Dateiname des Output-Files: <outputname.html>																	  ***/
/*** 																												  ***/
/*** 																												  ***/
/*** Grundriss des Programms: <Aufbereitung der Daten, deskriptive Auswertungen>						              ***/
/*** 																												  ***/
/*** 																												  ***/
/*** Verwendete Variablen: 																							  ***/
/*** Originalvariablen: 																							  ***/
/***		<sex: 				Geschlecht																			  ***/
/***		alter: 				Alter																				  ***/
/***		tage: 				Verweildauer																		  ***/
/***		icd_hd3: 			ICD-Code 3Steller Hauptdiagnose														  ***/
/***		icd_nd1-icd_nd89: 	ICD-Code Nebendiagnose																  ***/
/***		pat_typ_gem			Siedlungsstrukturelle Gebietstypen des Patienten>									  ***/
/*** 																												  ***/
/*** 																												  ***/
/*** Neu angelegte Variablen: 																						  ***/	
/***	    <kind: 				Dummyvariable Kind																	  ***/
/***     	alter5: 			gruppierte Altersvariable															  ***/
/***     	diabetes: 			Dummyvariable Diabetes mellitus Typ 2 in einer Nebendiagnose						  ***/
/***     	land:				Dummyvariable Regionsgrundtyp Lndliche Rume>										  ***/
/*** 																												  ***/
/*** Anmerkung: Falls Variablen verwendet werden, die in einer vorherigen Syntax erstellt wurden, 					  ***/
/*** diese bitte in separaten Blcken auflisten.																	  ***/
/************************************************************************************************************************/
/************************************************************************************************************************/



/************************************************************************************************************************/
/*** I.  Datenaufbereitung																							  ***/
/************************************************************************************************************************/

/************************************************************************************************************************/
/*** a. Formate definieren 																							  ***/

proc format;
	value dummy		0 = "nein"
					1 = "ja";

	value alter     1 = "0-19 Jahre" 
					2 = "20-39 Jahre" 
					3 = "40-59 Jahre"
					4 = "60-79 Jahre"
					5 = "80 Jahre und lter";
run;

%macro muster;


/************************************************************************************************************************/
/*** b. Auswahl der bentigten Berichtsjahre 																		  ***/

%do year = 2005 %to 2016; /*** BITTE HIER DIE VERWENDETEN BERICHTSJAHRE AUSWHLEN 									  ***/

data drg_&year;
set daten.&datenname.&year


/************************************************************************************************************************/
/*** c. Auswahl der bentigten Variablen 																			  ***/

(keep =  
/*** BITTE HIER DIE BENTIGTEN VARIABLEN ALLER BERICHTSJAHRE ANGEBEN 												  ***/
sex
alter
tage 
icd_hd3
icd_nd:

/*** Bei Auswahl von Variablen, die nicht in allen Jahren vorhanden sind, knnen diese Variablen im Anschluss an die  ***/
/*** Liste mit IF-Bedingungen ausgewhlt werden 																	  ***/
%if &year >= 2006 & &year <= 2010 %then %do;
pat_typ_gem
%end;


/************************************************************************************************************************/
/*** d. Auswahl der bentigten Flle 																				  ***/

/*** Ausschluss aller Flle mit Alter "unbekannt", Geschlecht "unbekannt" und/oder ohne Diabetes-Hauptdiagnose        ***/

/*** BITTE HIER AUSSCHLIELICH DIE FR DIE WEITERE AUSWERTUNG BENTIGTEN FLLE EINLESEN                               ***/
where = ( alter ~= 999 & sex ~= "u" & icd_hd3 in ("E65", "E66", "E67", "E68"))
);


/************************************************************************************************************************/
/*** e. Erstellung einer gruppierten Altersvariablen "alter5" 														  ***/

alter5 = 0;
if alter < 20 then alter5 = 1;
if alter >= 20 & alter < 40 then alter5 = 2;
if alter >= 40 & alter < 60 then alter5 = 3;
if alter >= 60 & alter < 80 then alter5 = 4;
if alter >= 80 then alter5 = 5;


/************************************************************************************************************************/
/*** f. Erstellung einer Dummyvariablen "kind" 																		  ***/

kind=0;
if alter >= 0 & alter <= 17 then kind = 1;


/************************************************************************************************************************/
/*** g. Erstellung einer Dummyvariablen Regionsgrundtyp Lndliche Rume "land" fr die Berichtsjahre 2006 bis 2010 	  ***/

%if &year >= 2006 & &year <= 2010 %then %do;
land = 0;
if pat_typ_gem >= 14 & pat_typ_gem <= 17 then land = 1;
%end;


/************************************************************************************************************************/
/*** h. Erstellung einer Dummyvariablen "diabetes", die angibt, ob in einer der 89 Nebendiagnosen die ersten  	      ***/
/***    3 Stellen "Diabetes mellitus Typ 2" ("E11") sind. 															  ***/

/*** Die Erstellung wurde mit Hilfe des Makros "newvar" durchgefhrt. Informationen hierzu finden sich unter:		  ***/ 
/*** https://www.forschungsdatenzentrum.de/sites/default/files/arbeitspapier-44.pdf 								  ***/

/*** Anpassen der Parameter zur Erstellung der Dummyvariablen 														  ***/
%let user_file = ;  		/*** Makrovariable bleibt innerhalb eines Datasteps leer 								  ***/
%let user_liste = "E11"; 	/*** Name der gesuchten Nebendiagnose "E11" 											  ***/
                           	/*** (Alle hierarchisch untergeordneten Diagnosen werden automatisch mit ausgewhlt)      ***/
%let user_block = icd_nd; 	/*** Angabe, dass ICD-Nebendiagnosen betrachtet werden 									  ***/
%let user_funktion = dummy; /*** Festlegung, dass eine Dummyvariable erstellt werden soll 							  ***/
%let user_name = diabetes;  /*** Name der neuen Dummyvariablen 														  ***/

/*** Ausfhren des Makros (Diese Sequenz muss unverndert in das Nutzer-Programm bernommen werden)                   ***/
%newvar(file = &user_file, liste = %quote(&user_liste), block = &user_block, funktion = &user_funktion, name = &user_name);


/************************************************************************************************************************/
/*** i. Beschriftung der Variablen und Werte 																		  ***/

label
   			kind 	 = "Dummyvariable Kind"
			alter5 	 = "gruppierte Altersvariable"
			diabetes = "numerische Dummyvariable, Diabetes mellitus Typ 2 in einer Nebendiagnose"
%if &year >= 2006 & &year <= 2010 %then %do;
			land     = "Dummyvariable Regionsgrundtyp Lndliche Rume"
%end;
;
format      kind dummy.
            alter5 alter.
			diabetes dummy.
%if &year >= 2006 & &year <= 2010 %then %do;
			land dummy.
%end;
;						
run; 



/************************************************************************************************************************/
/*** II.  Datenauswertung																							  ***/
/************************************************************************************************************************/

/*** Aufzeichnung des Outputfiles starten																			  ***/
ods html file = "&outputpfad./&outputname.&year..html";

/************************************************************************************************************************/
/*** a. Auswertungen mit Filterbedingungen 																			  ***/

/*** Restgren, die sich als Differenz zu "Insgesamt" erschlieen, sind zu vermeiden. 								  ***/
/*** Beispiel: Sie erzeugen eine "Insgesamt"-Tabelle und eine Tabelle "Kinder". 									  ***/
/*** Die Restgre/Differenz ist "Erwachsene" und muss mit ausgegeben werden. 										  ***/ 

/*** Output Nr. 1a-c: Hufigkeit der Adipositas-Flle nach Gesamt, Kinder und Erwachsene 							  ***/
proc freq data = drg_&year; 
title "Output Nr. 1a: Adipositas-Flle &year. , Gesamt";
table icd_hd3;
run;

proc freq data = drg_&year;
title "Output Nr. 1b: Adipositas-Flle &year. , nur Kinder";
where kind = 1;
table icd_hd3;
run;

proc freq data = drg_&year;
title "Output Nr. 1c: Adipositas-Flle &year., nur Erwachsene";
where kind = 0;
table icd_hd3;
run;

/*** Hinweis: Alternativ kann fr diese Art der Auswertung auch eine Kreuztabelle ohne vorherige Fallauswahl 	      ***/ 
/*** verwendet werden. Durch die Verwendung einer Kreuztabelle werden Restgren direkt vermieden.                    ***/


/************************************************************************************************************************/
/*** b. Ausgabe deskriptiver Kennzahlen 																			  ***/

/*** Aus Geheimhaltunsgrnden sind Minima und Maxima metrischer Variablen zu unterdrcken. 							  ***/

/*** Output Nr. 2: Anzahl, Mittelwert und Standardabweichung der Verweildauer aller Kinder 							  ***/
proc means data = drg_&year n mean std;
title "Output Nr. 2: Anzahl, Mittelwert und Standardabweichung der Verweildauer aller Kinder, &year.";
var tage;
where kind = 1;
run;


/************************************************************************************************************************/
/*** c. Auswertungen von Dummy-Variablen 																			  ***/

/*** Zustzlich zum Proc-Means-Befehl ist die Hufigkeitstabelle auszugeben, da die Fallzahl der Merkmalsausprgungen ***/
/*** fr die Geheimhaltungsprfung bentigt wird. 																	  ***/
 
/*** Output Nr. 3a-b: Anzahl, Mittelwert und Standardabweichung des gruppierten Alters aller Erwachsenen (kind = 0),  ***/
/*** Berichtsjahr																									  ***/
proc means data = drg_&year n mean std;
title "Output Nr. 3a: Anzahl, Mittelwert und Standardabweichung des Alters aller Erwachsenen (kind = 0), &year.";
var alter5;
where kind = 0;
run;

proc freq data = drg_&year;
title "Output Nr. 3b: Hufigkeitsauszhlung des Alters aller Erwachsenen (kind = 0), &year.";
tables alter5;
where kind = 0;
run;


/************************************************************************************************************************/
/*** d. Ausgabe von Wertetabellen 																					  ***/

/*** Bei der Erstellung von Wertetabellen ist stets die zugrundeliegende Fallzahl mit anzugeben.					  ***/

/*** Erstellen einer benutzerdefinierten Tabelle (mit Anzahl), Mittelwert und gltige Hufigkeit (N) des Alters       ***/ 
/*** nach der Dummyvariablen "diabetes".																			  ***/	

/*** Output Nr. 4: Kreuztabelle Alter und Dummyvariable, ob eine der Nebendiagnosen Diabetes mellitus Typ 2 ist,      ***/ 
/*** fr den Regionsgrundtyp lndliche Rume																		  ***/																		
%if &year >= 2006 & &year <= 2010 %then %do;
proc tabulate data = drg_&year;
title "Output Nr. 4: Kreuztabelle Alter und Dummyvariable diabetes fr den Regionsgrundtyp lndliche Rume, &year.";
	var alter;
	class diabetes; 
	table alter * (mean N), diabetes;
	where land = 1;
run;
%end;

ods html close;

/************************************************************************************************************************/
/*** III. Lschen aller temporren Dateien, sobald sie nicht mehr bentigt werden								      ***/
/************************************************************************************************************************/

proc datasets library=work nolist;
delete drg_&year;
run;

/************************************************************************************************************************/
/************************************************************************************************************************/

%end;

%mend muster;

%muster


