/*** Stand: 02.01.2019                                                                                            ***/

/********************************************************************************************************************/
/***************************************** Musterprogramm Stata DRG-Statistik ***************************************/
                               
/*** Hinweis: Das Musterprogramm dient Ihnen zur Orientierung bei der Erstellung Ihres Programmcodes.             ***/
/*** Das Ziel ist Ihre Outputfiles bestmöglich für die Geheimhaltungsprüfung aufzubereiten.                       ***/
/*** Bitte beachten Sie: Dieses Musterprogramm enthält keine statistikspezifischen Hilfestellungen zur            ***/
/*** Aufbereitung und Auswertung der von Ihnen beantragten Daten.                                                 ***/
                                                                                                                    
/********************************************************************************************************************/

clear all

/*** Version festlegen																							  ***/
version 14   /*** Version einfügen                                                                                ***/

/*** Bildschirmausgabe steuern																					  ***/
set more off
set logtype text
set linesize 255 

/*** Ado-Pfad festlegen																							  ***/
sysdir set PERSONAL "<Pfad wird im Forschungsdatenzentrum ergänzt>\"

mata mata mlib index

/*** Makros für Pfade																							  ***/
global datenpfad <Pfad wird im Forschungsdatenzentrum ergänzt>\
global outputpfad <Pfad wird im Forschungsdatenzentrum ergänzt>\

/*** Makros für Datei- und Outputnamen																			  ***/						
global dateiname <Dateiname wird im Forschungsdatenzentrum ergänzt>
global outputname <Name des Outputs spezifizieren, z.B. outputname>															  

/*** Auswahl der benötigten Berichtsjahre 																          ***/
foreach year of numlist 2005/2016 { /*** BITTE HIER DIE VERWENDETEN BERICHTSJAHRE AUSWÄHLEN 			    	  ***/

/*** Aufzeichung im Protokoll starten.                                                                            ***/
log using "$outputpfad\$outputname`year'.log", replace

/********************************************************************************************************************/
/********************************************************************************************************************/
/********************************************************************************************************************/


/********************************************************************************************************************/
/********************************************************************************************************************/
/*** Titel des Projekts: 			<Adipositas bei Kindern und Erwachsenen>    								  ***/
/*** Datengrundlage: 				<DRG 2005-2016>																  ***/
/***																										      ***/
/*** Dateiname des Programmcodes: 	<syntaxname.do>																  ***/
/*** erstellt: 						<Datum> 																	  ***/
/*** von: 							<Name> 																	      ***/
/*** E-Mail: 						<E-Mail-Adresse> 															  ***/
/*** Tel.: 							<Telefonnummer> 															  ***/
/*** 																											  ***/
/*** Dateiname des Output-Files: 	<outputname.log> 															  ***/
/*** 																											  ***/
/*** 																											  ***/
/*** Grundriss des Programms: <Aufbereitung der Daten, deskriptive Auswertungen>								  ***/
/*** 																											  ***/
/*** 																											  ***/ 
/*** Verwendete Variablen:    																					  ***/
/*** Originalvariablen: 																						  ***/
/***		<sex: 				Geschlecht																		  ***/
/***		alter: 				Alter																			  ***/
/***		tage: 				Verweildauer																	  ***/
/***		icd_hd3: 			ICD-Code 3Steller Hauptdiagnose													  ***/
/***		icd_nd1-icd_nd89: 	ICD-Code Nebendiagnose															  ***/
/***		pat_typ_gem			Siedlungsstrukturelle Gebietstypen des Patienten>								  ***/
/*** 																											  ***/
/*** Neu angelegte Variablen: 																					  ***/	
/***	    <kind: 				Dummyvariable Kind																  ***/
/***     	alter5: 			gruppierte Altersvariable														  ***/
/***     	diabetes: 			Dummyvariable Diabetes mellitus Typ 2 in einer Nebendiagnose					  ***/
/***     	land:				Dummyvariable Regionsgrundtyp Ländliche Räume>									  ***/
/*** 																											  ***/
/*** Anmerkung: Falls Variablen verwendet werden, die in einer vorherigen Syntax erstellt wurden, 				  ***/
/*** diese bitte in separaten Blöcken auflisten.																  ***/
/********************************************************************************************************************/
/********************************************************************************************************************/


/********************************************************************************************************************/
/*** I.  Datenaufbereitung																					      ***/
/********************************************************************************************************************/


/********************************************************************************************************************/
/*** a. Auswahl der benötigten Variablen und Fälle													              ***/

/*** Speicher- und laufzeiteffizient die Auswahl der benötigten Variablen und Fälle direkt nach Jahren vornehmen  ***/

if `year' == 2005 | `year' >= 2011 {
	use sex alter tage icd_hd3 icd_nd1-icd_nd89 ///
	using $datenpfad\$dateiname`year' if alter != 999 & sex != "u" & ///
	(icd_hd3 == "E65" | icd_hd3 == "E66" | icd_hd3 == "E67" | icd_hd3 == "E68"), clear
}

if `year' >= 2006 & `year' <= 2010 {
	use sex alter tage icd_hd3 icd_nd1-icd_nd89 pat_typ_gem ///
	using $datenpfad\$dateiname`year' if alter != 999 & sex != "u" & ///
	(icd_hd3 == "E65" | icd_hd3 == "E66" | icd_hd3 == "E67" | icd_hd3 == "E68"), clear
}

				
/********************************************************************************************************************/
/*** c. Erstellung einer gruppierten Altersvariable "alter5"													  ***/

generate alter5 = 0
replace alter5 = 1 if alter < 20
replace alter5 = 2 if alter >= 20 & alter < 40
replace alter5 = 3 if alter >= 40 & alter < 60
replace alter5 = 4 if alter >= 60 & alter < 80
replace alter5 = 5 if alter >= 80					


/********************************************************************************************************************/
/*** d. Erstellung einer Dummyvariablen "kind"																	  ***/

generate kind = 0
replace kind = 1 if alter >= 0 & alter <= 17 


/********************************************************************************************************************/
/*** e. Erstellung einer Dummyvariablen Regionsgrundtyp Ländliche Räume "land" für die Berichtsjahre 			  ***/
/***    2006 bis 2010																							  ***/

if `year' >= 2006 & `year' <= 2010 {																					
	generate land = 0
	replace land = 1 if pat_typ_gem >= "14" & pat_typ_gem <= "17"
}


/********************************************************************************************************************/
/*** f. Erstellung einer Dummyvariablen "diabetes", die angibt, ob in einer der 89 Nebendiagnosen die ersten	  ***/
/***	3 Stellen "Diabetes mellitus Typ 2" ("E11") sind                                                          ***/

foreach var of newlist diabetes1-diabetes89 {
	generate `var' = 0
}

foreach num of numlist 1/89 {
	replace diabetes`num' = 1 if substr(icd_nd`num',1,3) == "E11"
}
egen diabetes = anycount(diabetes*), values(1)
drop diabetes1-diabetes89


/********************************************************************************************************************/ 
/*** g. Beschriftung der Variablen und Werte																	  ***/

label define dummy	0 "nein" ///
					1 "ja"
					
label define alter5	1 "0-19 Jahre" ///
					2 "20-39 Jahre" ///
					3 "40-59 Jahre" ///
					4 "60-79 Jahre" ///
					5 "80 Jahre und älter"
					
label variable kind 	"Dummyvariable Kind"
label variable alter5 	"gruppierte Altersvariable"
label variable diabetes "numerische Dummyvariable, Diabetes mellitus Typ 2 in einer Nebendiagnose"
if `year' >= 2006 & `year' <= 2010 {
	label variable land 	"Dummyvariable Regionsgrundtyp Ländliche Räume"
}

label values kind dummy
label values alter5 alter5
label values diabetes dummy
if `year' >= 2006 & `year' <= 2010 {
	label values land dummy
}


/********************************************************************************************************************/
/*** II.  Datenauswertungen																						  ***/
/********************************************************************************************************************/

/********************************************************************************************************************/
/*** a. Auswertungen mit Filterbedingungen                                                                        ***/

/*** Restgrößen, die sich als Differenz zu "Insgesamt" erschließen, sind zu vermeiden.							  ***/
/*** Beispiel: Sie erzeugen eine "Insgesamt"-Tabelle und eine Tabelle "Kinder".									  ***/
/*** Die Restgröße/Differenz ist "Erwachsene" und muss mit ausgegeben werden. 									  ***/

/*** Output Nr. 1a: Häufigkeit der Adipositas-Fälle nach Gesamt                                                   ***/
tabulate icd_hd3

/*** Output Nr. 1b: Häufigkeit der Adipositas-Fälle nach Kindern                                                  ***/
tabulate icd_hd3 if kind==1

/*** Output Nr. 1c: Häufigkeit der Adipositas-Fälle nach Erwachsenen                                              ***/
tabulate icd_hd3 if kind==0

/*** Hinweis: Alternativ kann für diese Art der Auswertung auch eine Kreuztabelle ohne vorherige Fallauswahl      ***/
/*** verwendet werden. Durch die Verwendung einer Kreuztabelle werden Restgrößen direkt vermieden.                ***/


/********************************************************************************************************************/
/*** b. Ausgabe deskriptiver Kennzahlen                                                                           ***/

/*** Aus Geheimhaltungsgründen sind Minima und Maxima metrischer Variablen zu unterdrücken.                       ***/
/*** Die Verwendung des tabulate-Befehls ist bei der Ausgabe von deskriptiven Kennzahlen zu vermeiden.            ***/

/*** Output Nr. 2: Anzahl, Mittelwert und Standardabweichung der Verweildauer aller Kinder                        ***/

/*** Variante 1: Verwendung des tabstat-Befehls                                                                   ***/
tabstat tage if kind == 1, statistics(n mean sd) 

/*** Variante 2: Verwendung des sum-Befehls                                                                       ***/
/*** Bei Verwendung des sum-Befehls ist ein Umschreiben des Sum-Befehls nötig. Die Verwendung der Option detail   ***/
/*** ist zu vermeiden. Vorab muss das Ado-File "makematrix.ado" geladen werden.                                   ***/
makematrix, from(r(N) r(mean) r(sd)): sum tage if kind == 1


/********************************************************************************************************************/
/*** c. Auswertungen von Dummy-Variablen                                                                          ***/ 

/*** Zusätzlich zum Sum-Befehl ist die Kreuztabelle auszugeben, da die Fallzahl der Merkmalskombinationen für     ***/
/*** die Geheimhaltungsprüfung benötigt wird.                                                                     ***/
 
/*** Output Nr. 3a: Anzahl, Mittelwert und Standardabweichung des Alters aller Erwachsenen                        ***/
tabstat alter5 if kind == 0, statistics(n mean sd)

*** Output Nr. 3b: Häufigkeitsauszählung des Alters aller Erwachsenen
tabulate alter5 if kind == 0


/********************************************************************************************************************/
/*** d. Ausgabe von Wertetabellen                                                                                 ***/

/*** Bei der Erstellung von Wertetabellen ist stets die zugrundeliegende Fallzahl mit anzugeben.                  ***/

/*** Erstellen einer benutzerdefinierten Tabelle mit Anzahl und Mittelwert des Alters nach der Dummyvariablen     ***/ 
/*** "diabetes"                                                                                                   ***/

/*** Output Nr. 4: Kreuztabelle Alter und Dummyvariable, ob eine der Nebendiagnosen Diabetes mellitus Typ 2       ***/
/*** ist, für den Regionsgrundtyp ländliche Räume                                                                 ***/
if `year' >= 2006 & `year' <= 2010 {
tabstat alter if land == 1, statistics(mean count) by (diabetes)
}


/********************************************************************************************************************/

log close

}
